import { DataSource, ViewEntity, ViewColumn } from 'typeorm';
import { Carrito } from '../../../carrito/entity/carrito.entity';
import { Equipo } from '../equipo.entity';
import { Institucion } from '../../../institucion/entity/institucion.entity';
import { Marca } from '../../../marca/entity/marca.entity';
import { Modelo } from '../../../modelo/entity/modelo.entity';
import { Modulo } from '../../../modulo/entity/modulo.entity';
import { Status } from '../../../status/entity/status.entity';
import { TipoCarrito } from '../../../institucion-tipo-carrito/entity/tipo-carrito.entity';

@ViewEntity({
  expression: (dataSource: DataSource) =>
    dataSource
      .createQueryBuilder()
      .select('e.id_equipo', 'id_equipo')
      .addSelect('e.equipo', 'equipo')
      .addSelect('e.id_carrito', 'id_carrito')
      .addSelect('e.id_marca', 'id_marca')
      .addSelect('e.id_modelo', 'id_modelo')
      .addSelect('e.id_status', 'id_status')
      .addSelect('e.numero_inventario', 'numero_inventario')
      .addSelect('e.numero_serie', 'numero_serie')
      .addSelect('e.prestado', 'prestado')
      .addSelect('e.u', 'u')
      .addSelect('c.carrito', 'carrito')
      .addSelect('c.id_modulo', 'id_modulo')
      .addSelect('c.id_tipo_carrito', 'id_tipo_carrito')
      .addSelect('ma.marca', 'marca')
      .addSelect('mo.modelo', 'modelo')
      .addSelect('s.status', 'status')
      .addSelect('m.id_institucion', 'id_institucion')
      .addSelect('m.modulo', 'modulo')
      .addSelect('tc.tipo_carrito', 'tipo_carrito')
      .addSelect('i.institucion', 'institucion')
      .from(Equipo, 'e')
      .innerJoin(Carrito, 'c', 'c.id_carrito = e.id_carrito')
      .innerJoin(Marca, 'ma', 'ma.id_marca = e.id_marca')
      .innerJoin(Modelo, 'mo', 'mo.id_modelo = e.id_modelo')
      .innerJoin(Status, 's', 's.id_status = e.id_status')
      .innerJoin(Modulo, 'm', 'm.id_modulo = c.id_modulo')
      .innerJoin(TipoCarrito, 'tc', 'tc.id_tipo_carrito = c.id_tipo_carrito')
      .innerJoin(Institucion, 'i', 'i.id_institucion = m.id_institucion')
      .orderBy('institucion', 'ASC')
      .addOrderBy('modulo', 'ASC')
      .addOrderBy('tipo_carrito', 'ASC')
      .addOrderBy('carrito', 'ASC')
      .addOrderBy('equipo', 'ASC'),
})
export class FullInformacionEquipoView {
  @ViewColumn()
  id_equipo: number;

  @ViewColumn()
  carrito: string;

  @ViewColumn()
  equipo: string;

  @ViewColumn()
  id_carrito: number;

  @ViewColumn()
  id_institucion: number;

  @ViewColumn()
  id_marca: number;

  @ViewColumn()
  id_modelo: number;

  @ViewColumn()
  id_modulo: number;

  @ViewColumn()
  id_tipo_carrito: number;

  @ViewColumn()
  id_status: number;

  @ViewColumn()
  institucion: string;

  @ViewColumn()
  marca: string;

  @ViewColumn()
  modelo: string;

  @ViewColumn()
  modulo: string;

  @ViewColumn()
  numero_inventario: string;

  @ViewColumn()
  numero_serie: string;

  @ViewColumn()
  prestado: boolean;

  @ViewColumn()
  status: string;

  @ViewColumn()
  tipo_carrito: string;

  @ViewColumn()
  u: number;
}
