import { Controller, Get, Query, Request, UseGuards } from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import {
  ApiBearerAuth,
  ApiOperation,
  ApiQuery,
  ApiTags,
} from '@nestjs/swagger';
import { Serealize } from '../interceptors/serialize.interceptor';
import { InstitucionCarreraService } from './institucion-carrera.service';
import { ValidarUsuarioService } from '../validar-usuario/validar-usuario.service';
import { Operador } from '../operador/entity/operador.entity';
import { IdInstitucionDto } from '../dto/input/id-institucion.dto';
import { InstitucionCarreaOutputDto } from './dto/output/institucion-carrera.dto';

@Controller('institucion-carrera')
@ApiTags('institucion-carrera')
export class InstitucionCarreraController {
  constructor(
    private institucionCarreraService: InstitucionCarreraService,
    private validarUsuarioService: ValidarUsuarioService,
  ) {}

  @Serealize(InstitucionCarreaOutputDto)
  @Get('admin')
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description: 'Todas las carreras de la institución de un admin.',
  })
  @ApiBearerAuth('jwt')
  admin(@Request() req) {
    const admin: Operador = req.user.operador;

    this.validarUsuarioService.validarAdmin(admin);
    return this.institucionCarreraService.findAllAdmin(admin);
  }

  @Serealize(InstitucionCarreaOutputDto)
  @Get()
  @ApiOperation({ description: 'Todas las carreras de una institución.' })
  @ApiQuery({
    description: 'Id de la institución.',
    name: 'id_institucion',
    type: 'string',
  })
  get(@Query() query: IdInstitucionDto) {
    return this.institucionCarreraService.findAllByIdInstitucion(
      parseInt(query.id_institucion),
    );
  }

  @Serealize(InstitucionCarreaOutputDto)
  @Get('institucion-profesor')
  @ApiOperation({ description: 'Institución carrera de los profesores.' })
  @ApiQuery({
    description: 'Id de la institución.',
    name: 'id_institucion',
    type: 'string',
  })
  institucionProfesor(@Query() query: IdInstitucionDto) {
    return this.institucionCarreraService.findInstitucionProfesor(
      parseInt(query.id_institucion),
    );
  }
}
