import { Injectable, NotFoundException } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Not, Repository } from 'typeorm';
import { Carrera } from '../institucion-carrera/entity/carrera.entity';
import { Institucion } from '../institucion/entity/institucion.entity';
import { InstitucionCarrera } from './entity/institucion-carrera.entity';
import { Operador } from '../operador/entity/operador.entity';
import { InstitucionService } from '../institucion/institucion.service';

@Injectable()
export class InstitucionCarreraService {
  constructor(
    @InjectRepository(Carrera) private carreraRepository: Repository<Carrera>,
    @InjectRepository(InstitucionCarrera)
    private institucionCarreraRepository: Repository<InstitucionCarrera>,
    private institucionService: InstitucionService,
  ) {}

  findAllAdmin(admin: Operador): Promise<InstitucionCarrera[]> {
    return this.institucionCarreraRepository.find({
      where: { institucion: admin.institucion },
      order: { carrera: { carrera: 'ASC' } },
    });
  }

  findAllByIdInstitucion(
    id_institucion: number,
  ): Promise<InstitucionCarrera[]> {
    return this.institucionService
      .findById(id_institucion)
      .then((institucion) =>
        this.institucionCarreraRepository.find({
          where: { carrera: { id_carrera: Not(1) }, institucion },
          order: { carrera: { carrera: 'ASC' } },
        }),
      );
  }

  findById(id_institucion_carrera: number): Promise<InstitucionCarrera> {
    return this.institucionCarreraRepository
      .findOne({ where: { id_institucion_carrera } })
      .then((institucionCarrera) => {
        if (!institucionCarrera)
          throw new NotFoundException('No existe este id institución carrera.');
        return institucionCarrera;
      });
  }

  findByIdInstitucionIdCarrera(
    institucion: Institucion,
    carrera: Carrera,
  ): Promise<InstitucionCarrera> {
    return this.institucionCarreraRepository.findOne({
      where: { carrera, institucion },
    });
  }

  findCarreraByCarrera(
    carrera: string,
    validarNoExiste = true,
  ): Promise<Carrera> {
    return this.carreraRepository
      .findOne({ where: { carrera } })
      .then((carrera) => {
        if (validarNoExiste && !carrera)
          throw new NotFoundException('No existe esta carrera.');
        return carrera;
      });
  }

  findCarreraByIdCarrera(id_carrera: number): Promise<Carrera> {
    return this.carreraRepository
      .findOne({ where: { id_carrera } })
      .then((carrera) => {
        if (!carrera) throw new NotFoundException('No existe este id carrera.');
        return carrera;
      });
  }

  findInstitucionProfesor(id_institucion: number): Promise<InstitucionCarrera> {
    return this.institucionService
      .findById(id_institucion)
      .then((institucion) =>
        this.institucionCarreraRepository.findOne({
          where: { carrera: { id_carrera: 1 }, institucion },
        }),
      );
  }
}
